@@ -1,6 +1,6 @@
-# $Id: test.pl,v 4.1 2004/06/09 13:32:26 ronisaac Exp $
+# $Id: test.pl,v 5.2 2014/08/18 16:56:19 ronisaac Exp $
 
-# Copyright (c) 2001-2003, Morgan Stanley Dean Witter and Co.
+# Copyright (c) 2001-2014, Morgan Stanley.
 # Distributed under the terms of the GNU General Public License.
 # Please see the copyright notice in Modulecmd.pm for more information.
 
@@ -10,17 +10,18 @@ use Env::Modulecmd;
 BEGIN {
   # prepare test plan
 
-  plan tests => 3;
+  our $TESTS = 4;
+  plan tests => $TESTS;
 }
 
 # initialize environment
 
 eval { Env::Modulecmd::use ('.'); };
 
-if ($@ =~ /open3: exec of .* failed/) {
-  die <<MSG;
+if ($@ =~ /^Unable to execute/) {
+  print <<MSG;
 
-  ***** ERROR *****
+  ***** SKIPPING TESTS *****
 
   Env::Modulecmd was not able to invoke 'modulecmd'. This means
   one of two things:
@@ -40,7 +41,12 @@ if ($@ =~ /open3: exec of .* failed/) {
        c. Rebuild the Env::Modulecmd package with a default
           PERL_MODULECMD; see the README for more information
 
+  ***** SKIPPING TESTS *****
+
 MSG
+
+  skip ("Skip because modulecmd was not found", "") for (1..$TESTS);
+  exit;
 }
 
 die $@ if $@;
@@ -49,9 +55,14 @@ ok (1);
 # test loading
 
 Env::Modulecmd::load ('testmod');
-ok ($ENV{'TESTMOD_LOADED'} eq "yes" ? 2 : 0);
+ok ($ENV{'TESTMOD_LOADED'}, 'yes');
 
 # test unloading
 
 Env::Modulecmd::unload ('testmod');
-ok ($ENV{'TESTMOD_LOADED'} eq "yes" ? 0 : 3);
+ok ($ENV{'TESTMOD_LOADED'}, undef);
+
+# test failure
+
+eval { Env::Modulecmd::load ('no_such_module') };
+ok ($@, qr/Error loading module/);
